# Copyright (C) 2009-2012 Canonical, Ltd.
#
# This library is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License
# version 3.0 as published by the Free Software Foundation.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License version 3.0 for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library. If not, see
# <http://www.gnu.org/licenses/>.
"""The Ubuntu One Rhythmbox plugin."""

import os

# pylint: disable=E0611
from gi.repository import Gio, GLib, GObject, Peas
# pylint: enable=E0611

# pylint: disable=W0403
from MusicStoreWidget import U1MusicStoreWidget
# pylint: enable=W0403


class UbuntuOnePlugin (GObject.GObject, Peas.Activatable):
    """Ubuntu One integration for Rhythmbox."""
    __gtype_name__ = 'UbuntuOnePlugin'
    object = GObject.property(type=GObject.GObject)

    def __init__(self):
        GObject.GObject.__init__(self)

        # The folder where files get stored
        self.u1_library_path_url = 'file://{0}'.format(
            os.path.join(GLib.get_home_dir(),
                         '.ubuntuone',
                         'Purchased from Ubuntu One'))
        # RhythmDB settings so we can handle changes
        self.rdbconf = Gio.Settings('org.gnome.rhythmbox.rhythmdb')
        self.rdbconf.connect('changed::locations', self._locations_changed)

        # The Music Store itself
        self.music_store_widget = U1MusicStoreWidget(plugin=self)

    def _locations_changed(self, *args, **kwargs):
        """Handle the locations setting being changed."""
        libraries = self.rdbconf.get_strv('locations')
        if self.u1_library_path_url not in libraries:
            libraries.append(self.u1_library_path_url)
            self.rdbconf.set_strv('locations', libraries)

    def do_activate(self):
        """Plug-in startup."""
        # Add the Ubuntu One purchased music directory if not already added
        self._locations_changed()
        self.music_store_widget.activate(self.object)

    def do_deactivate(self):
        """Plug-in shutdown."""
        self.music_store_widget.deactivate(self.object)
